#
# spec file for package fwbuilder
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fwbuilder
Version:        5.3.7
Release:        7.12
Summary:        Firewall Builder
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://www.fwbuilder.org/
Source:         https://github.com/fwbuilder/fwbuilder/archive/v%{version}.tar.gz
Patch0:         fwbuilder-qmake-without-flags.patch
Patch1:         fix-bsc1124647-segfault.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-C-exception-specifications-are-deprecated-in-C-11.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  net-snmp-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
Requires:       hicolor-icon-theme
Requires:       rcs
%if 0%{?suse_version}
BuildRequires:  fdupes
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif

%description
Firewall Builder consists of a GUI and set of policy compilers for
various firewall platforms. It helps users maintain a database of
objects and allows policy editing using simple drag-and-drop
operations. The GUI generates a firewall description in the form of an XML
file, which compilers then interpret and generate platform-specific
code. Several algorithms are provided for automated network object
discovery and bulk import of data. The GUI and policy compilers are
independent of another.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh "--with-qmake=qmake-qt5"
%configure \
    --with-qmake=qmake-qt5 \
    --with-docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install
%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} System Security
%fdupes -s %{buildroot}
%endif

%files
%{_bindir}/*
%{_datadir}/applications/%{name}.desktop
%{_docdir}/%{name}
%{_datadir}/%{name}-%{version}
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man1/fwb*

%changelog
* Mon May 31 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with GCC 11:
  * 0001-C-exception-specifications-are-deprecated-in-C-11.patch
- Spec cleanup
* Thu Feb 14 2019 matthias.gerstner@suse.com
- Add fix-bsc1124647-segfault.patch: Fix crash described in bsc#1124647
* Wed Jan 31 2018 dimstar@opensuse.org
- Add fwbuilder-qmake-without-flags.patch: Fix build in case qmake
  is started without QMAKE_CXXFLAGS being defined
  (gh#fwbuilder/fwbuilder#46).
* Tue Dec 12 2017 joop.boonen@opensuse.org
- Build using Qt5 in stead of Qt4
* Tue Dec  5 2017 dimstar@opensuse.org
- Replace openssl-devel BuildRequires with pkgconfig(openssl):
  allow OBS to fallback to openssl 1.0, since this tool links Qt4
  (which is known not to be compatible with openssl 1.1).
* Wed Feb  8 2017 joop.boonen@opensuse.org
- Removed item from change log that shouldn't have been
  allowed via request 450449 it's not allowed to change
  and sertianly not insert changes in the changes file
* Wed Feb  8 2017 jengelh@inai.de
- Fix linguistic issues in description
* Tue Feb  7 2017 joop.boonen@opensuse.org
- Removed the service files as they are not compatible with opensuse
  they will for instance break the network settings
  As the script generated by fwbuilders includes iptables rules
  as wel as network interface settings
* Tue Feb  7 2017 joop.boonen@opensuse.org
- Use the Source link
- Revert the source split as it's not prefered
* Mon Feb  6 2017 chris@computersalat.de
- split package
  * build fwbuilder-service independently from fwbuilder
  * update changes file
* Sun Jan 15 2017 chris@computersalat.de
- Update to 5.3.7
  * iptables:
  - Feature: fwbuilder now supports conntrack instead of state module for recent iptables
  - Feature: Add support for the iptables > 1.4.20 "-w" option
  - Bugfix: Fixed (potential) deadlock situation as sugested by https://github.com/antaflos
  - Bugfix: Proper handling of NAT chains
  - Feature: Add support for --kerneltz
  * junos:
  - Bugfix: Generated new ids for the IP fragmentation service objects in the standard object database
  - Bugfix: Use correct comment symbol
  * gui:
  - Bugfix: Don't delete object in locked group
  - Feature: Add new objects directly to the subfolder via context menu
  * compiler:
  - Feature: Add support for MSYS2
  - Update OSX buildscript for newer XCode
  - Feature: Add support for GCC 6.X
  - Refactor: Gain more C++11 compatability
  - Feature: W32: Add support for MXE and provide Docker environment for cross compiling
* Sun Sep  4 2016 chris@computersalat.de
- add subpackage service/SysVinit
  * added systemd service / SysVinit file
  * added default file, which will be overwritten (sent) by
    fwbuilder GUI
  * noarch package
* Sun Jun 26 2016 joop.boonen@opensuse.org
- Build version 5.3.6 from the github repo
  * Several bugfixes for Junos, including rollback on syntax error,
    correct netmask for host objects and ssh password prompt lock-up
  * Support for Junos Access lists
  * Search for objects by port number or ip addres
  * View graphical diff and autocompile firewall when loading file
  * Support for Cisco NXOS Access lists
  * Added support for dummy objects in rules
  * Port to Qt5
- Deleted fwbuilder-gcc47.patch as it's not needed any more.
  The code has been fixed.
* Wed Sep  2 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file
- Use macros for updating of desktop files and icons
* Sat Dec  8 2012 joop.boonen@opensuse.org
- Added Requires rcs to enable reversion control
- Cleaned the spec file a bit more
* Wed Apr  4 2012 joop.boonen@opensuse.org
- Build version 5.1.0.3599
- Cleaned the spec file
* Sat Mar 17 2012 dimstar@opensuse.org
- Add fwbuilder-gcc47.patch: Fix build with gcc 4.7.
* Mon Jan 30 2012 cfarrell@suse.com
- license update: GPL-2.0+
* Wed Jan 25 2012 joop.boonen@opensuse.org
- Added automake and libtool as build requirement
- Used fdupes to get rid of duplicate files
- Libfwbuilder doesn't exist anymore for a long time,
  that's why the obsoletes removed
* Sat Jan  7 2012 joop.boonen@opensuse.org
- Build version 5.0.1.3592
* Mon Aug  8 2011 joop.boonen@opensuse.org
- Build version 5.0.0.3568
* Mon May 23 2011 joop.boonen@opensuse.org
- Build version 4.2.2.3541
* Thu Apr 21 2011 joop.boonen@opensuse.org
- Build version 4.2.0.3530
* Tue Jan  4 2011 joop.boonen@opensuse.org
- Build version 4.1.3
* Sat Oct  9 2010 joop.boonen@opensuse.org
- Build version 4.1.2
* Wed Aug 25 2010 joop.boonen@opensuse.org
- Build version 4.1.1
* Tue Jul 20 2010 joop.boonen@opensuse.org
- Build version 4.0.2
* Wed Jun  2 2010 joop.boonen@opensuse.org
- Build version 4.0.1
* Mon Sep 21 2009 joop.boonen@opensuse.org
- Build version 3.0.7
* Fri Sep  4 2009 joop.boonen@opensuse.org
- combined to one fwbuilder package as the orginal rpm is
  also one package. To be on the safe side.
* Thu Sep  3 2009 joop.boonen@opensuse.org  
- some improvements
* Tue Sep  1 2009 chris@computersalat.de
- cleanup spec
- fixed deps
* Mon Aug 31 2009 joop.boonen@opensuse.org
- build release 3.0.6
* Thu Aug 20 2009 chris@computersalat.de
- added AUTHORS to description
* Wed Jun 17 2009 joop.boonen@opensuse.org
- build release 3.0.5
* Wed Apr  8 2009 joop.boonen@opensuse.org
- adapted the spec file so it meets the package convention
  http://en.opensuse.org/SUSE_Package_Conventions/RPM_Style
* Fri Apr  3 2009 bitshuffler #suse@irc.freenode.org
- Cleaned up the spec
* Thu Apr  2 2009 joop.boonen@opensuse.org  
- build release 3.0.4
* Mon Mar 23 2009 joop.boonen@opensuse.org  
- Applied patch requested bij openSuSE contrib approvers
* Thu Mar  5 2009 joop.boonen@opensuse.org  
- Perfecting the spec file first step
* Tue Mar  3 2009 joop.boonen@opensuse.org  
- Using bz2 in stead of gz file
* Wed Dec 17 2008 joop.boonen@opensuse.org  
- build release 3.0.3
* Sun Oct 12 2008 joop.boonen@opensuse.org    
- Started off with the fwbuilder Mandrake spec file
* Sun Oct 12 2008 joop.boonen@opensuse.org    
- Initial version by Vadim Kurland <vadim@fwbuilder.org>
